@@ -5,7 +5,8 @@ import pytest
 from bs4 import BeautifulSoup
 
 import tests.html_schema_doc_asserts
-from json_schema_for_humans.generate import generate_from_file_object, GenerationConfiguration
+from json_schema_for_humans.generate import generate_from_file_object
+from json_schema_for_humans.generation_configuration import GenerationConfiguration
 from tests.test_utils import generate_case
 
 
@@ -224,10 +225,12 @@ def test_with_definitions():
 
     tests.html_schema_doc_asserts.assert_property_names(
         soup,
-        ["billing_address", "street_address", "city", "state", "shipping_address"],
+        ["billing_address", "street_address", "city", "state", "futureProperty", "shipping_address"],
     )
-    tests.html_schema_doc_asserts.assert_types(soup, ["object", "object", "string", "string", "string", "object"])
-    tests.html_schema_doc_asserts.assert_required(soup, [False, True, True, True, False])
+    tests.html_schema_doc_asserts.assert_types(
+        soup, ["object", "object", "string", "string", "string", "null", "object"]
+    )
+    tests.html_schema_doc_asserts.assert_required(soup, [False, True, True, True, False, False])
 
 
 def test_with_multiple_descriptions():
